window.Gleam.initSearch([{"doc":"simplifile","title":"simplifile","content":"# simplifile\n\n[![Package Version](https://img.shields.io/hexpm/v/simplifile)](https://hex.pm/packages/simplifile)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/simplifile/)\n\nSimplifile provides basic file operations (read, write, append, and delete) that work\nfor all targets (Erlang, Node, and Deno). It also provides functions for working with directories.\n\n## Example\n```gleam\nlet filepath = &quot;./test/hello.txt&quot;\nlet assert Ok(_) = &quot;Hello, World&quot; |&gt; write(to: filepath)\nlet assert Ok(_) = &quot;Goodbye, Mars&quot; |&gt; append(to: filepath)\nlet assert Ok(&quot;Hello, WorldGoodbye, Mars&quot;) = read(from: filepath)\nlet assert Ok(_) = delete(filepath)\nlet assert Error(_) = read(from: filepath)\n```\n\n## Quick start\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add simplifile\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/simplifile&gt;.\n","url":"index.html"},{"doc":"simplifile","title":"FileError","content":"pub type FileError {\n  Eacces\n  Eagain\n  Ebadf\n  Ebadmsg\n  Ebusy\n  Edeadlk\n  Edeadlock\n  Edquot\n  Eexist\n  Efault\n  Efbig\n  Eftype\n  Eintr\n  Einval\n  Eio\n  Eisdir\n  Eloop\n  Emfile\n  Emlink\n  Emultihop\n  Enametoolong\n  Enfile\n  Enobufs\n  Enodev\n  Enolck\n  Enolink\n  Enoent\n  Enomem\n  Enospc\n  Enosr\n  Enostr\n  Enosys\n  Enotblk\n  Enotdir\n  Enotsup\n  Enxio\n  Eopnotsupp\n  Eoverflow\n  Eperm\n  Epipe\n  Erange\n  Erofs\n  Espipe\n  Esrch\n  Estale\n  Etxtbsy\n  Exdev\n  NotUtf8\n  Unknown\n}\n This type represents all of the reasons for why a file system operation could fail.\n\n Most of these reasons are POSIX errors, which come from the operating system\n and start with E. Others have been added to represent other issues that may\n arise specific to this library.\n\nEacces\n Permission denied.\n\nEagain\n Resource temporarily unavailable.\n\nEbadf\n Bad file number\n\nEbadmsg\n Bad message.\n\nEbusy\n File busy.\n\nEdeadlk\n Resource deadlock avoided.\n\nEdeadlock\n On most architectures, same as `Edeadlk`. On some architectures, it\n means &quot;File locking deadlock error.&quot;\n\nEdquot\n Disk quota exceeded.\n\nEexist\n File already exists.\n\nEfault\n Bad address in system call argument.\n\nEfbig\n File too large.\n\nEftype\n Inappropriate file type or format. Usually caused by trying to set the\n &quot;sticky bit&quot; on a regular file (not a directory).\n\nEintr\n Interrupted system call.\n\nEinval\n Invalid argument.\n\nEio\n I/O error.\n\nEisdir\n Illegal operation on a directory.\n\nEloop\n Too many levels of symbolic links.\n\nEmfile\n Too many open files.\n\nEmlink\n Too many links.\n\nEmultihop\n Multihop attempted.\n\nEnametoolong\n Filename too long\n\nEnfile\n File table overflow\n\nEnobufs\n No buffer space available.\n\nEnodev\n No such device.\n\nEnolck\n No locks available.\n\nEnolink\n Link has been severed.\n\nEnoent\n No such file or directory.\n\nEnomem\n Not enough memory.\n\nEnospc\n No space left on device.\n\nEnosr\n No STREAM resources.\n\nEnostr\n Not a STREAM.\n\nEnosys\n Function not implemented.\n\nEnotblk\n Block device required.\n\nEnotdir\n Not a directory.\n\nEnotsup\n Operation not supported.\n\nEnxio\n No such device or address.\n\nEopnotsupp\n Operation not supported on socket.\n\nEoverflow\n Value too large to be stored in data type.\n\nEperm\n Not owner.\n\nEpipe\n Broken pipe.\n\nErange\n Result too large.\n\nErofs\n Read-only file system.\n\nEspipe\n Invalid seek.\n\nEsrch\n No such process.\n\nEstale\n Stale remote file handle.\n\nEtxtbsy\n Text file busy.\n\nExdev\n Cross-domain link.\n\nNotUtf8\n File was requested to be read as UTF-8, but is not UTF-8 encoded.\n\nUnknown\n Any error not accounted for by this type\n\nSynonyms:\nsimplifile.FileError\nsimplifile FileError","url":"simplifile.html#FileError"},{"doc":"simplifile","title":"append","content":"pub fn append(contents: String, to filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Append a string to the contents of a file at the given path\n ## Example\n \n let assert Ok(Nil) = append(&quot;more text&quot;, to: &quot;./needs_more_text.txt&quot;)\n \n\nSynonyms:\nsimplifile.append\nsimplifile append","url":"simplifile.html#append"},{"doc":"simplifile","title":"append_bits","content":"pub fn append_bits(bits: BitString, to filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Append a bitstring to the contents of a file at the given path\n ## Example\n \n let assert Ok(Nil) = append_bits(&lt;&lt;&quot;more text&quot;:utf8&gt;&gt;, to: &quot;./needs_more_text.txt&quot;)\n \n\nSynonyms:\nsimplifile.append_bits\nsimplifile append_bits","url":"simplifile.html#append_bits"},{"doc":"simplifile","title":"copy_directory","content":"pub fn copy_directory(at src: String, to dest: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Copy a directory recursively\nSynonyms:\nsimplifile.copy_directory\nsimplifile copy_directory","url":"simplifile.html#copy_directory"},{"doc":"simplifile","title":"copy_file","content":"pub fn copy_file(at src: String, to dest: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Copy a file at a given path to another path.\n Note: destination should include the filename, not just the directory\nSynonyms:\nsimplifile.copy_file\nsimplifile copy_file","url":"simplifile.html#copy_file"},{"doc":"simplifile","title":"create_directory","content":"pub fn create_directory(filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Create a directory at the provided filepath. Returns an error if\n the directory already exists.\n\n ## Example\n \n create_directory(&quot;./test&quot;)\n \nSynonyms:\nsimplifile.create_directory\nsimplifile create_directory","url":"simplifile.html#create_directory"},{"doc":"simplifile","title":"create_directory_all","content":"pub fn create_directory_all(dirpath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Recursively creates necessary directories for a given directory\n path. Note that if you pass a path that &quot;looks like&quot; a file, i.e.\n `./a/b.txt`, a folder named `b.txt` will be created, so be sure\n to pass only the path to the required directory.\nSynonyms:\nsimplifile.create_directory_all\nsimplifile create_directory_all","url":"simplifile.html#create_directory_all"},{"doc":"simplifile","title":"create_file","content":"pub fn create_file(at filepath: String) -&gt; Result(Nil, FileError)\n Creates an empty file at the given filepath. Returns an `Error(Eexist)`\n if the file already exists.\n \nSynonyms:\nsimplifile.create_file\nsimplifile create_file","url":"simplifile.html#create_file"},{"doc":"simplifile","title":"delete","content":"pub fn delete(file_or_dir_at path: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Delete a file or directory at a given path. Performs a recursive\n delete on a directory.\n Throws an error if the path does not exist.\n ## Example\n \n let assert Ok(Nil) = delete(file_at: &quot;./delete_me.txt&quot;)\n \n\nSynonyms:\nsimplifile.delete\nsimplifile delete","url":"simplifile.html#delete"},{"doc":"simplifile","title":"delete_all","content":"pub fn delete_all(paths paths: List(String)) -&gt; Result(\n  Nil,\n  FileError,\n)\n Delete all files/directories specified in a list of paths.\n Recursively deletes provided directories.\n Does not return an error if one or more of the provided paths \n do not exist. \n \nSynonyms:\nsimplifile.delete_all\nsimplifile delete_all","url":"simplifile.html#delete_all"},{"doc":"simplifile","title":"is_directory","content":"pub fn is_directory(filepath: String) -&gt; Bool\n Checks if the provided filepath is a directory\n ## Example\n \n let assert True = is_directory(&quot;./test&quot;)\n \nSynonyms:\nsimplifile.is_directory\nsimplifile is_directory","url":"simplifile.html#is_directory"},{"doc":"simplifile","title":"is_file","content":"pub fn is_file(filepath: String) -&gt; Bool\n Returns `True` if there is a file at the given path, false otherwise.\n \nSynonyms:\nsimplifile.is_file\nsimplifile is_file","url":"simplifile.html#is_file"},{"doc":"simplifile","title":"list_contents","content":"pub fn list_contents(of directory: String) -&gt; Result(\n  List(String),\n  FileError,\n)\n Lists the contents of a directory.\n The list contains directory and file names, and is not recursive.\n \n ## Example\n \n let assert Ok(files_and_folders) = list_contents(of: &quot;./Folder1&quot;)\n \n \nSynonyms:\nsimplifile.list_contents\nsimplifile list_contents","url":"simplifile.html#list_contents"},{"doc":"simplifile","title":"read","content":"pub fn read(from filepath: String) -&gt; Result(String, FileError)\n Read a files contents as a string\n ## Example\n \n let assert Ok(records) = read(from: &quot;./users.csv&quot;)\n \n\nSynonyms:\nsimplifile.read\nsimplifile read","url":"simplifile.html#read"},{"doc":"simplifile","title":"read_bits","content":"pub fn read_bits(from filepath: String) -&gt; Result(\n  BitString,\n  FileError,\n)\n Read a files contents as a bitstring\n ## Example\n \n let assert Ok(records) = read_bits(from: &quot;./users.csv&quot;)\n \n\nSynonyms:\nsimplifile.read_bits\nsimplifile read_bits","url":"simplifile.html#read_bits"},{"doc":"simplifile","title":"rename_directory","content":"pub fn rename_directory(at src: String, to dest: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Copy a directory recursively and then delete the old one.\nSynonyms:\nsimplifile.rename_directory\nsimplifile rename_directory","url":"simplifile.html#rename_directory"},{"doc":"simplifile","title":"rename_file","content":"pub fn rename_file(at src: String, to dest: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Rename a file at a given path to another path.\n Note: destination should include the filename, not just the directory\nSynonyms:\nsimplifile.rename_file\nsimplifile rename_file","url":"simplifile.html#rename_file"},{"doc":"simplifile","title":"write","content":"pub fn write(contents: String, to filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Write a string to a file at the given path\n ## Example\n \n let assert Ok(Nil) = write(&quot;Hello, World!&quot;, to: &quot;./hello_world.txt&quot;)\n \n\nSynonyms:\nsimplifile.write\nsimplifile write","url":"simplifile.html#write"},{"doc":"simplifile","title":"write_bits","content":"pub fn write_bits(bits: BitString, to filepath: String) -&gt; Result(\n  Nil,\n  FileError,\n)\n Write a bitstring to a file at the given path\n ## Example\n \n let assert Ok(Nil) = write_bits(&lt;&lt;&quot;Hello, World!&quot;:utf8&gt;&gt;, to: &quot;./hello_world.txt&quot;)\n \n\nSynonyms:\nsimplifile.write_bits\nsimplifile write_bits","url":"simplifile.html#write_bits"},{"doc":"simplifile","title":"simplifile","content":"","url":"simplifile.html"}]);